@@ -53,6 +53,9 @@ IconApplet::~IconApplet()
     if (destroyed()) {
         QFile::remove(m_localPath);
     }
+    if (m_openWithMenu) {
+        m_openWithMenu->deleteLater();
+    }
 }
 
 void IconApplet::init()
@@ -340,10 +343,10 @@ QList<QAction *> IconApplet::extraActions()
                 m_fileItemActions->setItemListProperties(itemProperties);
 
                 if (!m_openWithMenu) {
-                    m_openWithMenu.reset(new QMenu());
+                    m_openWithMenu = new QMenu;
                 }
                 m_openWithMenu->clear();
-                m_fileItemActions->insertOpenWithActionsTo(nullptr, m_openWithMenu.get(), QStringList());
+                m_fileItemActions->insertOpenWithActionsTo(nullptr, m_openWithMenu, QStringList());
 
                 m_openWithActions = m_openWithMenu->actions();
             }
