@@ -449,6 +449,7 @@ void DWDIon::parseForecastData(const QString source, QJsonDocument doc)
             forecast->period = QDateTime::fromString(period, QStringLiteral("yyyy-MM-dd"));
             forecast->tempHigh = parseNumber(dayMap[QStringLiteral("temperatureMax")]);
             forecast->tempLow = parseNumber(dayMap[QStringLiteral("temperatureMin")]);
+            forecast->precipitation = dayMap[QStringLiteral("precipitation")].toInt();
             forecast->iconName = getWeatherIcon(dayIcons(), cond);
             ;
 
@@ -484,15 +485,8 @@ void DWDIon::parseForecastData(const QString source, QJsonDocument doc)
         for (const QVariant &warningElement : warningData) {
             QMap warningMap = warningElement.toMap();
 
-            QString warningDesc = warningMap[QStringLiteral("description")].toString();
-
-            // This loop adds line breaks because the weather widget doesn't seem to do that which completly ruins the layout
-            // Should be removed if the weather widget is ever fixed
-            for (int i = 1; i <= (warningDesc.size() / 50); i++) {
-                warningDesc.insert(i * 50, QChar::LineFeed);
-            }
-
-            warning->description = warningDesc;
+            warning->headline = warningMap[QStringLiteral("headline")].toString();
+            warning->description = warningMap[QStringLiteral("description")].toString();
             warning->priority = warningMap[QStringLiteral("level")].toInt();
             warning->type = warningMap[QStringLiteral("event")].toString();
             warning->timestamp = QDateTime::fromMSecsSinceEpoch(warningMap[QStringLiteral("start")].toLongLong());
@@ -624,8 +618,11 @@ void DWDIon::updateWeather(const QString &source)
 
     int dayNumber = 0;
     for (const WeatherData::ForecastInfo *dayForecast : weatherData.forecasts) {
-        if (dayNumber > 0) {
-            QString period = dayForecast->period.toString(QStringLiteral("dddd"));
+        QString period;
+        if (dayNumber == 0) {
+            period = i18nc("Short for Today", "Today");
+        } else {
+            period = dayForecast->period.toString(QStringLiteral("dddd"));
 
             period.replace(QStringLiteral("Saturday"), i18nc("Short for Saturday", "Sat"));
             period.replace(QStringLiteral("Sunday"), i18nc("Short for Sunday", "Sun"));
@@ -634,23 +631,15 @@ void DWDIon::updateWeather(const QString &source)
             period.replace(QStringLiteral("Wednesday"), i18nc("Short for Wednesday", "Wed"));
             period.replace(QStringLiteral("Thursday"), i18nc("Short for Thursday", "Thu"));
             period.replace(QStringLiteral("Friday"), i18nc("Short for Friday", "Fri"));
-
-            data.insert(QStringLiteral("Short Forecast Day %1").arg(dayNumber),
-                        QStringLiteral("%1|%2|%3|%4|%5|%6")
-                            .arg(period, dayForecast->iconName, QLatin1String(""))
-                            .arg(dayForecast->tempHigh)
-                            .arg(dayForecast->tempLow)
-                            .arg(QLatin1String("")));
-            dayNumber++;
-        } else {
-            data.insert(QStringLiteral("Short Forecast Day %1").arg(dayNumber),
-                        QStringLiteral("%1|%2|%3|%4|%5|%6")
-                            .arg(i18nc("Short for Today", "Today"), dayForecast->iconName, QLatin1String(""))
-                            .arg(dayForecast->tempHigh)
-                            .arg(dayForecast->tempLow)
-                            .arg(QLatin1String("")));
-            dayNumber++;
         }
+
+        data.insert(QStringLiteral("Short Forecast Day %1").arg(dayNumber),
+                    QStringLiteral("%1|%2|%3|%4|%5|%6")
+                        .arg(period, dayForecast->iconName, QLatin1String(""))
+                        .arg(dayForecast->tempHigh)
+                        .arg(dayForecast->tempLow)
+                        .arg(QLatin1String(""))); // dayForecast->precipitation is a quantity, not a probability
+        dayNumber++;
     }
 
     int k = 0;
@@ -659,7 +648,7 @@ void DWDIon::updateWeather(const QString &source)
         const QString number = QString::number(k);
 
         data.insert(QStringLiteral("Warning Priority ") + number, warning->priority);
-        data.insert(QStringLiteral("Warning Description ") + number, warning->description);
+        data.insert(QStringLiteral("Warning Description ") + number, QStringLiteral("<p><b>%1</b></p>%2").arg(warning->headline, warning->description));
         data.insert(QStringLiteral("Warning Timestamp ") + number, warning->timestamp.toString(QStringLiteral("dd.MM.yyyy")));
 
         ++k;
