@@ -75,7 +75,7 @@ KlipperPopup::KlipperPopup(History *history)
         screen = QGuiApplication::screens()[0];
     }
     int menuHeight = (screen->geometry().height()) * 3 / 4;
-    int menuWidth = (screen->geometry().width()) * 1 / 3;
+    int menuWidth = std::min((screen->geometry().width()) * 1 / 3, 640);
 
     m_popupProxy = new PopupProxy(this, menuHeight, menuWidth);
 
@@ -104,8 +104,7 @@ void KlipperPopup::ensureClean()
 
 void KlipperPopup::buildFromScratch()
 {
-    addSection(QIcon::fromTheme(QStringLiteral("klipper")),
-               i18nc("%1 is application display name", "%1 - Clipboard Items", QGuiApplication::applicationDisplayName()));
+    addSection(QIcon::fromTheme(QStringLiteral("klipper")), i18n("Clipboard Items"));
 
     m_filterWidget = new KLineEdit(this);
     m_filterWidget->setFocusPolicy(Qt::NoFocus);
