@@ -208,7 +208,7 @@ void PlayerContainer::setLoopStatus(LoopStatus::Status value)
     default:
         Q_UNREACHABLE();
     }
-    m_propsIface->Set(OrgMprisMediaPlayer2PlayerInterface::staticInterfaceName(), QStringLiteral("LoopStatus"), QDBusVariant(result));
+    m_propsIface->Set(QStringLiteral("org.mpris.MediaPlayer2.Player"), QStringLiteral("LoopStatus"), QDBusVariant(result));
     // Emit changed signals in onPropertiesChanged
 }
 
@@ -227,7 +227,7 @@ void PlayerContainer::setRate(double value)
         return;
     }
 
-    m_propsIface->Set(OrgMprisMediaPlayer2PlayerInterface::staticInterfaceName(), QStringLiteral("Rate"), QDBusVariant(QVariant(value)));
+    m_propsIface->Set(QStringLiteral("org.mpris.MediaPlayer2.Player"), QStringLiteral("Rate"), QDBusVariant(QVariant(value)));
     // Emit changed signals in onPropertiesChanged
 }
 
@@ -237,9 +237,7 @@ void PlayerContainer::setShuffle(ShuffleStatus::Status value)
         return;
     }
 
-    m_propsIface->Set(OrgMprisMediaPlayer2PlayerInterface::staticInterfaceName(),
-                      QStringLiteral("Shuffle"),
-                      QDBusVariant(QVariant(value == ShuffleStatus::On)));
+    m_propsIface->Set(QStringLiteral("org.mpris.MediaPlayer2.Player"), QStringLiteral("Shuffle"), QDBusVariant(QVariant(value == ShuffleStatus::On)));
     // Emit changed signals in onPropertiesChanged
 }
 
@@ -249,7 +247,7 @@ void PlayerContainer::setVolume(double value)
         return;
     }
 
-    m_propsIface->Set(OrgMprisMediaPlayer2PlayerInterface::staticInterfaceName(), QStringLiteral("Volume"), QDBusVariant(QVariant(value)));
+    m_propsIface->Set(QStringLiteral("org.mpris.MediaPlayer2.Player"), QStringLiteral("Volume"), QDBusVariant(QVariant(value)));
     // Emit changed signals in onPropertiesChanged
 }
 
@@ -330,7 +328,7 @@ void PlayerContainer::setFullscreen(bool value)
         return;
     }
 
-    m_propsIface->Set(OrgMprisMediaPlayer2Interface::staticInterfaceName(), QStringLiteral("Fullscreen"), QDBusVariant(QVariant(value)));
+    m_propsIface->Set(QStringLiteral("org.mpris.MediaPlayer2"), QStringLiteral("Fullscreen"), QDBusVariant(QVariant(value)));
     // Emit changed signals in onPropertiesChanged
 }
 
@@ -408,13 +406,12 @@ void PlayerContainer::refresh()
     // despite these calls being async, we should never update values in the
     // wrong order (eg: a stale GetAll response overwriting a more recent value
     // from a PropertiesChanged signal) due to D-Bus message ordering guarantees.
-
-    QDBusPendingCall async = m_propsIface->GetAll(OrgMprisMediaPlayer2Interface::staticInterfaceName());
+    QDBusPendingCall async = m_propsIface->GetAll(QStringLiteral("org.mpris.MediaPlayer2"));
     auto watcher = new QDBusPendingCallWatcher(async, this);
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &PlayerContainer::onGetPropsFinished);
     ++m_fetchesPending;
 
-    async = m_propsIface->GetAll(OrgMprisMediaPlayer2PlayerInterface::staticInterfaceName());
+    async = m_propsIface->GetAll(QStringLiteral("org.mpris.MediaPlayer2.Player"));
     watcher = new QDBusPendingCallWatcher(async, this);
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &PlayerContainer::onGetPropsFinished);
     ++m_fetchesPending;
@@ -422,7 +419,7 @@ void PlayerContainer::refresh()
 
 void PlayerContainer::updatePosition()
 {
-    QDBusPendingCall call = m_propsIface->Get(OrgMprisMediaPlayer2PlayerInterface::staticInterfaceName(), QStringLiteral("Position"));
+    QDBusPendingCall call = m_propsIface->Get(QStringLiteral("org.mpris.MediaPlayer2.Player"), QStringLiteral("Position"));
     auto watcher = new QDBusPendingCallWatcher(call, this);
     connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *watcher) {
         QDBusPendingReply<QVariant> propsReply = *watcher;
@@ -568,9 +565,8 @@ void PlayerContainer::updateFromMap(const QVariantMap &map)
         if (propName == QLatin1String("Identity")) {
             updateSingleProperty(m_identity, it.value(), QMetaType::QString, &PlayerContainer::identityChanged);
         } else if (propName == QLatin1String("DesktopEntry")) {
-            QString iconName = KDesktopFile(it.value().toString() + QLatin1String(".desktop")).readIcon();
-            if (!iconName.isEmpty()) {
-                m_iconName = iconName;
+            if (QString iconName = KDesktopFile(it.value().toString() + QLatin1String(".desktop")).readIcon(); !iconName.isEmpty()) {
+                m_iconName = std::move(iconName);
             }
             updateSingleProperty(m_desktopEntry, it.value(), QMetaType::QString, &PlayerContainer::desktopEntryChanged);
         } else if (propName == QLatin1String("SupportedUriSchemes")) {
@@ -713,8 +709,12 @@ void PlayerContainer::onGetPropsFinished(QDBusPendingCallWatcher *watcher)
     }
 }
 
-void PlayerContainer::onPropertiesChanged(const QString &, const QVariantMap &changedProperties, const QStringList &invalidatedProperties)
+void PlayerContainer::onPropertiesChanged(const QString &interfaceName, const QVariantMap &changedProperties, const QStringList &invalidatedProperties)
 {
+    if (interfaceName != QLatin1String("org.mpris.MediaPlayer2.Player") && interfaceName != QLatin1String("org.mpris.MediaPlayer2")) {
+        // org.mpris.MediaPlayer2.TrackList is ignored for now
+        return;
+    }
     if (!invalidatedProperties.empty()) {
         disconnect(m_propsIface, &OrgFreedesktopDBusPropertiesInterface::PropertiesChanged, this, &PlayerContainer::onPropertiesChanged);
         disconnect(m_playerIface, &OrgMprisMediaPlayer2PlayerInterface::Seeked, this, &PlayerContainer::onSeeked);
