@@ -9,9 +9,6 @@
 #include "screencasting.h"
 #include <QObject>
 
-class ScreencastingStream;
-struct ScreencastingRequestPrivate;
-
 /**
  * Allows us to request a stream for a window identified by its universally
  * unique identifier.
@@ -30,12 +27,12 @@ class ScreencastingRequest : public QObject
      * @see PlasmaWindowModel::Uuid
      * @see TasksModel::WinIdList
      */
-    Q_PROPERTY(QString uuid READ uuid WRITE setUuid NOTIFY uuidChanged)
+    Q_PROPERTY(QString uuid READ uuid WRITE setUuid RESET resetUuid NOTIFY uuidChanged)
 
     /**
      * The output name as define in Screen.name
      */
-    Q_PROPERTY(QString outputName READ outputName WRITE setOutputName NOTIFY outputNameChanged)
+    Q_PROPERTY(QString outputName READ outputName WRITE setOutputName RESET resetOutputName NOTIFY outputNameChanged)
 
     /** The offered nodeId to give to a source */
     Q_PROPERTY(quint32 nodeId READ nodeId NOTIFY nodeIdChanged)
@@ -43,10 +40,14 @@ public:
     ScreencastingRequest(QObject *parent = nullptr);
     ~ScreencastingRequest();
 
+    void resetUuid();
     void setUuid(const QString &uuid);
     QString uuid() const;
+
+    void resetOutputName();
     void setOutputName(const QString &outputName);
     QString outputName() const;
+
     quint32 nodeId() const;
 
 Q_SIGNALS:
@@ -55,8 +56,12 @@ Q_SIGNALS:
     void outputNameChanged(const QString &outputNames);
 
 private:
-    void adopt(ScreencastingStream *stream);
     void setNodeid(uint nodeId);
+    void setStream(std::unique_ptr<ScreencastingStream> stream);
 
-    std::unique_ptr<ScreencastingRequestPrivate> d;
+    std::unique_ptr<Screencasting> m_screenCasting;
+    std::unique_ptr<ScreencastingStream> m_stream;
+    QString m_uuid;
+    QString m_outputName;
+    quint32 m_nodeId = 0;
 };
