@@ -5,7 +5,9 @@
 */
 
 #include <QDir>
-#include <QtTest>
+#include <QSignalSpy>
+#include <QTest>
+#include <QThreadPool>
 
 #include "commontestdata.h"
 #include "finder/imagefinder.h"
@@ -16,6 +18,7 @@ class ImageFinderTest : public QObject
 
 private Q_SLOTS:
     void initTestCase();
+    void cleanupTestCase();
     void testImageFinderCanFindImages();
 
 private:
@@ -26,6 +29,12 @@ void ImageFinderTest::initTestCase()
 {
     m_dataDir = QDir(QFINDTESTDATA("testdata/default"));
     QVERIFY(!m_dataDir.isEmpty());
+    renameBizarreFile(m_dataDir);
+}
+
+void ImageFinderTest::cleanupTestCase()
+{
+    restoreBizarreFile(m_dataDir);
 }
 
 void ImageFinderTest::testImageFinderCanFindImages()
